--------------------------------------------------------------------------------
-- SubModule FanoutDiag
-- Created   8/1/2008 10:34:40 AM
--------------------------------------------------------------------------------
library IEEE;
use IEEE.Std_Logic_1164.all;

entity FanoutDiag is port
   (
     UP            : in    std_logic_vector(1 to 4);
     LOS           : in    std_logic_vector(1 to 4);
     MISSING       : in    std_logic_vector(1 to 4);
     DLYERR        : in    std_logic_vector(1 to 4);
     ERRC          : in    std_logic_vector(31 downto 0);
     DELAY         : in    std_logic_vector(127 downto 0);
     FIXED         : in    std_logic_vector(127 downto 0);
     A             : in    std_logic_vector(1 downto 0);
     D             : out   std_logic_vector(31 downto 0);
     MSW           : in    std_logic
   );
end FanoutDiag;
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
architecture Structure of FanoutDiag is

-- Component Declarations

-- Signal Declarations
   signal delayctrl           : std_logic_vector (31 downto 0);
   signal delayerr            : std_logic_vector (31 downto 0);

begin
   delay_ctrl: process (A, UP, LOS, MISSING, DLYERR, ERRC, FIXED) is
   begin
      case A is
         when B"00" =>
            delayctrl <= FIXED (22 downto 5) & B"00" & ERRC (7 downto 0) &
                         MISSING(1) & DLYERR(1) & LOS(1) & UP(1);
         when B"01" =>
            delayctrl <= FIXED (54 downto 37) & B"00" & ERRC (15 downto 8) &
                         MISSING(2) & DLYERR(2) & LOS(2) & UP(2);
         when B"10" =>
            delayctrl <= FIXED (86 downto 69) & B"00" & ERRC (23 downto 16) &
                         MISSING(3) & DLYERR(3) & LOS(3) & UP(3);
         when others =>
            delayctrl <= FIXED (118 downto 101) & B"00" & ERRC (31 downto 24) &
                         MISSING(4) & DLYERR(4) & LOS(4) & UP(4);
      end case;
   end process delay_ctrl;

   delay_err: process (A, DELAY) is
   begin
      case A is
         when B"00" =>
            delayerr <= DELAY (31 downto 0);
         when B"01" =>
            delayerr <= DELAY (63 downto 32);
         when B"10" =>
            delayerr <= DELAY (95 downto 64);
         when others =>
            delayerr <= DELAY (127 downto 96);
      end case;
   end process delay_err;

   ms_word: process (MSW, delayctrl, delayerr) is
   begin
      if MSW = '0' then
         D <= delayerr;
      else
         D <= delayctrl;
      end if;
   end process ms_word;

end architecture Structure;
--------------------------------------------------------------------------------
